==> metview_4.6.1.orig.tar.xz: metview-4.6.1/src/MacroEditor/ShellHelper.cc <==
/***************************** LICENSE START ***********************************

 Copyright 2012 ECMWF and INPE. This software is distributed under the terms
 of the Apache License version 2.0. In applying this license, ECMWF does not
 waive the privileges and immunities granted to it by virtue of its status as
 an Intergovernmental Organization or submit itself to any jurisdiction.

 ***************************** LICENSE END *************************************/

#include <string>
using std::string;


#include "LanguageHelper.h" 
#include "ShellHelper.h" 
#include "Highlighter.h"



// -----------------------------------------------------------------------
// ------------------- Syntax highlighter code ---------------------------
//        this class is used by the MagMLHelper object, defined below
// -----------------------------------------------------------------------


// -----------------------------------------------------------------------
// ------------------- Syntax highlighter code ---------------------------
//        this class is used by the PlainTextHelper object, defined below
// -----------------------------------------------------------------------


class ShellHighlighter : public Highlighter
{
public:
     ShellHighlighter(QTextDocument *parent = 0);
    ~ShellHighlighter(){}

     virtual void highlightBlock(const QString &text);

};


ShellHighlighter::ShellHighlighter(QTextDocument *parent)
     : Highlighter(parent)
{
}



void ShellHighlighter::highlightBlock(const QString &text)
{
    foreach (HighlightingRule rule, highlightingRules) 
    {
        QRegExp expression(rule.pattern);
        int index = text.indexOf(expression);
        while (index >= 0) 
        {
            int length = expression.matchedLength();
            setFormat(index, length, rule.format);
            index = text.indexOf(expression, index + length);
        }
    }
}






// -----------------------------------------------------------------------
// -------------------------- ShellHelper code ---------------------------
// -----------------------------------------------------------------------


// ---------------------------------------------------------------------------
// ShellHelper::ShellHelper
// constructor
// ---------------------------------------------------------------------------

ShellHelper::ShellHelper()
{
    languageName_ = "Shell";
    className_    = "SHELL";
    serviceName_  = "(x=`dirname \"%s\"`;cd \"$x\" ; sh \"%s\")";
}


// ---------------------------------------------------------------------------
// ShellHelper::~ShellHelper
// destructor
// ---------------------------------------------------------------------------

ShellHelper::~ShellHelper()
{
}


// ---------------------------------------------------------------------------
// ShellHelper::~createHighlighter
// creates a new syntax highlighter object
// ---------------------------------------------------------------------------

Highlighter *ShellHelper::createHighlighter(QTextDocument *parent)
{
    return new ShellHighlighter(parent);
}


// ---------------------------------------------------------------------------
// ShellHelper::isHeaderLine
// decides whether the given line is a shell script header line
// ---------------------------------------------------------------------------

bool ShellHelper::isHeaderLine(const QString &text)
{
    return (text.contains("#") && 
            text.contains("bin") &&
            (text.contains("sh") || text.contains("ksh") || text.contains("csh")));
}

==> metview_5.3.0.orig.tar.xz: metview-5.3.0/src/MacroEditor/ShellHelper.cc <==
/***************************** LICENSE START ***********************************

 Copyright 2012 ECMWF and INPE. This software is distributed under the terms
 of the Apache License version 2.0. In applying this license, ECMWF does not
 waive the privileges and immunities granted to it by virtue of its status as
 an Intergovernmental Organization or submit itself to any jurisdiction.

 ***************************** LICENSE END *************************************/

#include <string>
using std::string;


#include "LanguageHelper.h" 
#include "ShellHelper.h" 
#include "Highlighter.h"



// -----------------------------------------------------------------------
// ------------------- Syntax highlighter code ---------------------------
//        this class is used by the MagMLHelper object, defined below
// -----------------------------------------------------------------------


// -----------------------------------------------------------------------
// ------------------- Syntax highlighter code ---------------------------
//        this class is used by the PlainTextHelper object, defined below
// -----------------------------------------------------------------------


class ShellHighlighter : public Highlighter
{
public:
     ShellHighlighter(QTextDocument *parent = 0);
    ~ShellHighlighter(){}

     virtual void highlightBlock(const QString &text);

};


ShellHighlighter::ShellHighlighter(QTextDocument *parent)
     : Highlighter(parent)
{
}



void ShellHighlighter::highlightBlock(const QString &text)
{
    foreach (HighlightingRule rule, highlightingRules) 
    {
        QRegExp expression(rule.pattern);
        int index = text.indexOf(expression);
        while (index >= 0) 
        {
            int length = expression.matchedLength();
            setFormat(index, length, rule.format);
            index = text.indexOf(expression, index + length);
        }
    }
}






// -----------------------------------------------------------------------
// -------------------------- ShellHelper code ---------------------------
// -----------------------------------------------------------------------


// ---------------------------------------------------------------------------
// ShellHelper::ShellHelper
// constructor
// ---------------------------------------------------------------------------

ShellHelper::ShellHelper()
{
    languageName_ = "Shell";
    className_    = "SHELL";
    serviceName_  = "(x=`dirname \"%s\"`;cd \"$x\" ; sh \"%s\")";
}


// ---------------------------------------------------------------------------
// ShellHelper::~ShellHelper
// destructor
// ---------------------------------------------------------------------------

ShellHelper::~ShellHelper()
{
}


// ---------------------------------------------------------------------------
// ShellHelper::~createHighlighter
// creates a new syntax highlighter object
// ---------------------------------------------------------------------------

Highlighter *ShellHelper::createHighlighter(QTextDocument *parent)
{
    return new ShellHighlighter(parent);
}


// ---------------------------------------------------------------------------
// ShellHelper::isHeaderLine
// decides whether the given line is a shell script header line
// ---------------------------------------------------------------------------

bool ShellHelper::isHeaderLine(const QString &text)
{
    return (text.contains("#") && 
            text.contains("bin") &&
            (text.contains("sh") || text.contains("ksh") || text.contains("csh") || text.contains("bash")));
}
